@@ -9,10 +9,11 @@
     :license: BSD, see LICENSE for more details.
 """
 from .client import LineClient
-from .models import LineGroup, LineContact, LineRoom
+from .api import LineAPI
+from .models import LineGroup, LineContact, LineRoom, LineBase, LineMessage
 
 __copyright__ = 'Copyright 2014 by Taehoon Kim'
-__version__ = '0.1.5'
+__version__ = '0.1.7'
 __license__ = 'BSD'
 __author__ = 'Taehoon Kim'
 __author_email__ = 'carpedm20@gmail.com'
@@ -22,5 +23,7 @@ __all__ = [
     # LineClient object
     'LineClient',
     # model wrappers for LINE API
-    'LineGroup', 'LineContact', 'LineRoom',
+    'LineGroup', 'LineContact', 'LineRoom', 'LineBase', 'LineMessage',
+    # Line Thrift API
+    'LineAPI', 
 ]
