@@ -10,6 +10,10 @@
 """
 import rsa
 import requests
+try:
+    import simplejson as json
+except ImportError:
+    import json
 
 from thrift.transport import TTransport
 from thrift.transport import TSocket
@@ -68,9 +72,9 @@ class LineAPI(object):
     def login(self):
         """Login to LINE server."""
         if self.provider == CurveThrift.Provider.LINE: # LINE
-            j = self.get_json(self.LINE_SESSION_LINE_URL)
+            j = self._get_json(self.LINE_SESSION_LINE_URL)
         else: # NAVER
-            j = self.get_json(self.LINE_SESSION_NAVER_URL)
+            j = self._get_json(self.LINE_SESSION_NAVER_URL)
 
         session_key = j['session_key']
         message     = (chr(len(session_key)) + session_key +
@@ -97,7 +101,7 @@ class LineAPI(object):
         print "Enter PinCode '%s' to your mobile phone in 2 minutes"\
                 % self._pinCode
 
-        j = self.get_json(self.LINE_CERTIFICATE_URL)
+        j = self._get_json(self.LINE_CERTIFICATE_URL)
         self.verifier = j['result']['verifier']
 
         msg = self._client.loginWithVerifierForCertificate(self.verifier)
@@ -253,3 +257,7 @@ class LineAPI(object):
     def raise_error(self, msg):
         """Error format"""
         raise Exception("Error: %s" % msg)
+
+    def _get_json(self, url):
+        """Get josn from given url with saved session and headers"""
+        return json.loads(self._session.get(url, headers=self._headers).text)
