@@ -11,14 +11,9 @@
 import re
 import requests
 import sys
-from datetime import datetime
-try:
-    import simplejson as json
-except ImportError:
-    import json
 
 from api import LineAPI
-from models import LineGroup, LineContact, LineRoom
+from models import LineGroup, LineContact, LineRoom, LineMessage
 from curve.ttypes import TalkException, ToType, OperationType, Provider
 
 reload(sys)
@@ -27,28 +22,24 @@ sys.setdefaultencoding("utf-8")
 EMAIL_REGEX = re.compile(r"[^@]+@[^@]+\.[^@]+")
 
 class LineClient(LineAPI):
-    """Provie a way to communicate with LINE API
-
-        >>> client = LineClient(\'carpedm20\', \'xxxxxxxxxx\')
-        Enter PinCode '9779' to your mobile phone in 2 minutes
-        >>> client = LineClient(\'carpedm20@gmail.com\', \'xxxxxxxxxx\')
-        Enter PinCode '' to your mobile phone in 2 minutes
-        >>> print client.profile
-    """
-
     profile  = None
     contacts = []
     rooms    = []
     groups   = []
 
     def __init__(self, id=None, password=None, authToken=None, is_mac=True, com_name="carpedm20"):
-        """Initialize LINE instance with provided information
+        """Provide a way to communicate with LINE server.
 
         :param id: `NAVER id` or `LINE email`
         :param password: LINE account password
         :param authToken: LINE session key
         :param is_mac: (optional) os setting
         :param com_name: (optional) name of your system
+
+        >>> client = LineClient("carpedm20", "xxxxxxxxxx")
+        Enter PinCode '9779' to your mobile phone in 2 minutes
+        >>> client = LineClient("carpedm20@gmail.com", "xxxxxxxxxx")
+        Enter PinCode '7390' to your mobile phone in 2 minutes
         """
 
         if not (authToken or id and password):
@@ -95,7 +86,7 @@ class LineClient(LineAPI):
 
     def getProfile(self):
         """Get profile of LINE account"""
-        if self.check_auth():
+        if self._check_auth():
             self.profile = LineContact(self, self._getProfile())
 
             return self.profile
@@ -129,7 +120,7 @@ class LineClient(LineAPI):
 
     def refreshGroups(self):
         """Refresh groups of LineClient"""
-        if self.check_auth():
+        if self._check_auth():
             self.groups = []
 
             self.addGroupsWithIds(self._getGroupIdsJoined())
@@ -137,7 +128,7 @@ class LineClient(LineAPI):
 
     def addGroupsWithIds(self, group_ids, is_joined=True):
         """Refresh groups of LineClient"""
-        if self.check_auth():
+        if self._check_auth():
             new_groups  = self._getGroups(group_ids)
 
             for group in new_groups:
@@ -147,7 +138,7 @@ class LineClient(LineAPI):
 
     def refreshContacts(self):
         """Refresh contacts of LineClient """
-        if self.check_auth():
+        if self._check_auth():
             contact_ids = self._getAllContactIds()
             contacts    = self._getContacts(contact_ids)
 
@@ -160,7 +151,7 @@ class LineClient(LineAPI):
 
     def refreshActiveRooms(self):
         """Refresh active chat rooms"""
-        if self.check_auth():
+        if self._check_auth():
             start = 1
             count = 50
 
@@ -185,7 +176,7 @@ class LineClient(LineAPI):
         :param name: name of group
         :param ids: list of contact ids
         """
-        if self.check_auth():
+        if self._check_auth():
             try:
                 group = LineGroup(self, self._createGroup(name, ids))
                 self.groups.append(group)
@@ -202,7 +193,7 @@ class LineClient(LineAPI):
         :param name: name of group
         :param contacts: list of contacts
         """
-        if self.check_auth():
+        if self._check_auth():
             try:
                 contact_ids = []
                 for contact in contacts:
@@ -245,7 +236,7 @@ class LineClient(LineAPI):
         :param group: LineGroup instance
         :param contacts: LineContact instances to invite
         """
-        if self.check_auth():
+        if self._check_auth():
             contact_ids = [contact.id for contact in contacts]
             self._inviteIntoGroup(room.id, contact_ids)
 
@@ -254,7 +245,7 @@ class LineClient(LineAPI):
 
         :param group: LineGroup instance
         """
-        if self.check_auth():
+        if self._check_auth():
             try:
                 self._acceptGroupInvitation(group.id)
                 return True
@@ -267,7 +258,7 @@ class LineClient(LineAPI):
         
         :param group: LineGroup instance to leave
         """
-        if self.check_auth():
+        if self._check_auth():
             try:
                 self._leaveGroup(group.id)
                 self.groups.remove(group)
@@ -280,7 +271,7 @@ class LineClient(LineAPI):
 
     def createRoomWithIds(self, ids=[]):
         """Create a chat room with contact ids"""
-        if self.check_auth():
+        if self._check_auth():
             try:
                 room = LineRoom(self, self._createRoom(ids))
                 self.rooms.append(room)
@@ -293,7 +284,7 @@ class LineClient(LineAPI):
 
     def createRoomWithContacts(self, contacts=[]):
         """Create a chat room with contacts"""
-        if self.check_auth():
+        if self._check_auth():
             try:
                 contact_ids = []
                 for contact in contacts:
@@ -314,7 +305,7 @@ class LineClient(LineAPI):
         :param room: LineRoom instance
         :param contacts: LineContact instances to invite
         """
-        if self.check_auth():
+        if self._check_auth():
             contact_ids = [contact.id for contact in contacts]
             self._inviteIntoRoom(room.id, contact_ids)
 
@@ -323,7 +314,7 @@ class LineClient(LineAPI):
         
         :param room: LineRoom instance to leave
         """
-        if self.check_auth():
+        if self._check_auth():
             try:
                 self._leaveRoom(room.id)
                 self.rooms.remove(room)
@@ -339,7 +330,7 @@ class LineClient(LineAPI):
         
         :param message: LineMessage instance to send
         """
-        if self.check_auth():
+        if self._check_auth():
             self._sendMessage(message, seq)
 
     def getMessageBox(self, id):
@@ -347,7 +338,7 @@ class LineClient(LineAPI):
 
         :param id: `contact` id or `group` id or `room` id
         """
-        if self.check_auth():
+        if self._check_auth():
             try:
                 messageBoxWrapUp = self._getMessageBoxCompactWrapUp(id)
 
@@ -360,14 +351,14 @@ class LineClient(LineAPI):
 
         :param messageBox: MessageBox object
         """
-        if self.check_auth():
+        if self._check_auth():
             id = messageBox.id
             messages = self._getRecentMessages(id, count)
         
             return self.getLineMessageFromMessage(messages)
 
     def longPoll(self, count=50):
-        if self.check_auth():
+        if self._check_auth():
             """Check is there any operations from LINE server"""
             OT = OperationType
 
@@ -409,7 +400,7 @@ class LineClient(LineAPI):
 
         return lineMessages
 
-    def check_auth(self):
+    def _check_auth(self):
         """Check if client is logged in or not"""
         if self.authToken:
             return True
@@ -417,7 +408,3 @@ class LineClient(LineAPI):
             msg = "you need to login"
             self.raise_error(msg)
 
-    def get_json(self, url):
-        """Get josn from given url with saved session and headers"""
-        return json.loads(self._session.get(url, headers=self._headers).text)
-
